@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
+import functools
 import staticconf
 
 from git_code_debt.server.metric_config import CONFIG_NAMESPACE
@@ -9,6 +10,6 @@ from git_code_debt.server.metric_config import CONFIG_NAMESPACE
 watcher = staticconf.ConfigFacade.load(
     'metric_config.yaml',
     CONFIG_NAMESPACE,
-    staticconf.YamlConfiguration,
+    functools.partial(staticconf.YamlConfiguration, flatten=False),
     min_interval=30,
 )
